animateOnLoad property

bool animateOnLoad
finalinherited

Animates the Charts from zero values to given Data when the Chart loads for the first time.

Defaults to true.

Implementation

final bool animateOnLoad;