xValue property

num xValue
final

The Value along X-Axis for this BarGroup.

This value is not used for plotting on X-Axis. The plotting is done based on the index of this item in the list.

Implementation

final num xValue;