CartesianRangeResult class
A Result Wrapper that provides the X & Y Ranges and the unit values.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxXRange ↔ double
-
getter/setter pair
- maxYRange ↔ double
-
getter/setter pair
- minXRange ↔ double
-
getter/setter pair
- minYRange ↔ double
-
getter/setter pair
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setterinherited - xUnitValue ↔ double
-
getter/setter pair
- yUnitValue ↔ double
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lerp(
CartesianRangeResult? current, CartesianRangeResult target, double t) → CartesianRangeResult