spacing property
The space between consecutive bars in a series arrangement.
Note: If you've chosen arrangement as stack, then spacing will be ignored.
Implementation
final double spacing;
The space between consecutive bars in a series arrangement.
Note: If you've chosen arrangement as stack, then spacing will be ignored.
final double spacing;