onDrag property

void Function(PieInteractionResult interactionResult)? onDrag
finalinherited

onDrag is called when the pointer location is updated for the pointer that started the drag gesture.

Implementation

final void Function(T interactionResult)? onDrag;