SliceData constructor

const SliceData({
  1. required num value,
  2. ChartTextStyle? labelStyle,
  3. SliceMapper? label,
  4. SliceDataStyle? style,
})

Defines the Data of a Pie Slice in the Pie/Donut chart

Holds the Numeric Value, label and styling for this Slice

Implementation

const SliceData({
  required this.value,
  this.labelStyle,
  this.label,
  this.style,
});