animateOnLoad property
Animates the Charts from zero values to given Data when the Chart loads for the first time.
Defaults to true.
Implementation
final bool animateOnLoad;
Animates the Charts from zero values to given Data when the Chart loads for the first time.
Defaults to true.
final bool animateOnLoad;