onDrag property
onDrag is called when the pointer location is updated for the pointer that started
the drag gesture.
Implementation
final void Function(T interactionResult)? onDrag;
onDrag is called when the pointer location is updated for the pointer that started
the drag gesture.
final void Function(T interactionResult)? onDrag;