RadialChartStyle class
Provides the Styling options for any Radial Chart.
Customization Options include BackgroundColor, Start Angle and Axis Styling.
Constructors
- RadialChartStyle({Color backgroundColor = const Color(0xFFF7FFF7), double initAngle = 0.0, RadialAxis? axis})
-
const
Properties
- axis → RadialAxis?
-
Styling for the Axis Lines.
final
- backgroundColor → Color
-
The Background Color of the Chart.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initAngle → double
-
The Angle from which the Initial Data Should begin.
Defaults to zero and starts Vertically Upright.
final
-
props
→ List<
Object> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
copyWith(
{Color? backgroundColor, double? initAngle}) → RadialChartStyle -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited