SliceData constructor
const
SliceData({
- required num value,
- ChartTextStyle? labelStyle,
- SliceMapper? label,
- SliceDataStyle? style,
Defines the Data of a Pie Slice in the Pie/Donut chart
Holds the Numeric Value, label and styling for this Slice
Implementation
const SliceData({
required this.value,
this.labelStyle,
this.label,
this.style,
});